MODEL_PARAMS_LIMIT = 3000000000  # Taking gemma-2 billion model parameters as maximum parameters tracebloc support
TENSORFLOW_FRAMEWORK = "tensorflow"
PYTORCH_FRAMEWORK = "pytorch"
SKLEARN_FRAMEWORK = "sklearn"
IMAGE_CLASSIFICATION = "image_classification"
TEXT_CLASSIFICATION = "text_classification"
KEYPOINT_DETECTION = "keypoint_detection"
OBJECT_DETECTION = "object_detection"
TABULAR_CLASSIFICATION = "tabular_classification"
SEMANTIC_SEGMENTATION = "semantic_segmentation"
INSTANCE_SEGMENTATION = "instance_segmentation"
YOLO = "yolo"
RCNN = "rcnn"
HEATMAP = "heatmap"
CONSTANT = "constant"
STANDARD = "standard"
ADAPTIVE = "adaptive"
CUSTOM = "custom"
TYPE = "type"
FUNCTION = "function"
VALUE = "value"
PRETRAINED_WEIGHTS_FILENAME = "pretrained_weights"
TRAINED_WEIGHTS_FILENAME = "trained_weights"
AVERAGED_WEIGHTS_PATH = "averaged"
SUCCESS = "success"
TORCH_HUB_PATTERN = "torch.hub"
DNN = "fcn"
ML = "ml"
